@@ -6,12 +6,12 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/helmfile/vals"
+	"github.com/stretchr/testify/assert"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
 	"github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
-	"github.com/helmfile/helmfile/pkg/testhelper"
 )
 
 func TestApply_2(t *testing.T) {
@@ -134,10 +134,7 @@ func TestApply_2(t *testing.T) {
 		if tc.log != "" {
 			actual := bs.String()
 
-			diff, exists := testhelper.Diff(tc.log, actual, 3)
-			if exists {
-				t.Errorf("unexpected log:\nDIFF\n%s\nEOD", diff)
-			}
+			assert.Equal(t, tc.log, actual)
 		} else {
 			assertLogEqualsToSnapshot(t, bs.String())
 		}
